@@ -10,7 +10,12 @@
 #' @examples
 #' elevation_shade(example_raster())
 #' @export
-elevation_shade <- function(raster_dem, elevation_palette = c("#54843f", "#808080", "#FFFFFF"), return_png = TRUE, png_opacity = 1){
+elevation_shade <- function(raster_dem, elevation_palette = c("#54843f", "#808080", "#FFFFFF"), return_png = TRUE, png_opacity = 0.9){
+
+  if(length(is.na(raster_dem)) > 0){
+    message("There are NA values in raster_dem. Assuming they are min(raster_dem[], na.rm = TRUE) for shading.")
+    raster_dem[is.na(raster_dem)] <- min(raster_dem[], na.rm = TRUE)
+  }
 
   rasterValues <- raster::values(raster_dem)
 
@@ -31,7 +36,7 @@ elevation_shade <- function(raster_dem, elevation_palette = c("#54843f", "#80808
 
   tempImage <- tempfile(fileext = ".png")
 
-  slippymath::raster_to_png(rasterImage, tempImage)
+  raster_to_png(rasterImage, tempImage)
 
   terrain_image <- png::readPNG(tempImage)
 
